Package 'rdoom'

Title: Doom
Description: Doom.
Authors: John Carmack [aut, cph] (Original Doom Author), Mike Cheng [aut, cre, cph] (Author of R interface and sound handling)
Maintainer: Mike Cheng <[email protected]>
License: GPL (>= 2)
Version: 1.0.0
Built: 2026-07-07 05:40:01 UTC
Source: https://github.com/coolbutuseless/rdoom

Help Index


Run doom in demo mode. No keyboard input.

Description

Run doom in demo mode. No keyboard input.

Usage

doom(
  wad_file = system.file("doom1.wad", package = "rdoom", mustWork = TRUE),
  mouse = FALSE,
  sensitivity = 150,
  sound = FALSE,
  keymap = keymap_default(),
  ...
)

Arguments

wad_file

full path to WAD file. Default: use the demo 'doom1.wad' included with this package.

mouse

use the mouse? Default: FALSE

sensitivity

75

sound

use sound? Default: FALSE. Very experimental. Needs the "audio" package to be installed.

keymap

created with 'keymap_default()' or 'keymap_create()'

...

further options passed to tigerfb::fb_open()

Value

None


Create an sanitise a keymap specification.

Description

See also: keymap_default()

Usage

keymap_create(...)

Arguments

...

name/value pairs with the name representing a valid 'tigerfb' key name (See tigerfb::fb_key_names()), and the value representing a doom key name (See configuratble_doom_keys)

Examples

tigerfb::fb_key_names()
configurable_doom_keys
keymap_create(d = "KEY_STRAFE_R", ...)

Create a default keymap

Description

Note: multiple keys can map to a doom function. In the default keymap, both SPACE and CTRL map to "KEY_FIRE"

Usage

keymap_default()

Value

named list of key mappings from tigerfb to doom